@@ -5,9 +5,7 @@ use namespace::autoclean;
 our $VERSION = '0.02';
 $VERSION = eval $VERSION;
 
-has is_success  => ( is => 'ro', isa => 'Str', required => 1 );
 has api_call    => ( is => 'ro', isa => 'Str' );
-has error       => ( is => 'ro', isa => 'Str' );
 has ticket      => ( is => 'ro', isa => 'Str' );
 has unused      => ( is => 'ro', isa => 'Int' );
 has basic       => ( is => 'ro', isa => 'Int' );
@@ -29,58 +27,56 @@ WebService::VaultPress::Partner::Response - The VaultPress Partner API Client Re
 
 =head1 VERSION
 
-version 0.01.00
+version 0.03
 
 =head1 SYNOPSIS
-
+  
   #!/usr/bin/perl
   use warnings;
   use strict;
-  use Carp;
+  use lib 'lib';
   use WebService::VaultPress::Partner;
-
-  my $VP = WebService::VaultPress::Partner->new(
-      key => 'Your Key Goes Here',
+  
+  
+  my $vp = WebService::VaultPress::Partner->new(
+      key => 'Your API Key Goes Here',
   );
-
-  sub handle_error {
-      my ( $res ) = @_;
-      croak "Failed during " . $res->api_call . " with error: " . $res->error
-          unless $res->is_success;
-  }
-
-  # How many people signed up.
-  my $result = $VP->GetUsage; 
   
-  handle_error($result);
-
-  printf( "%7s => %5d\n", $_, $result->$_ ) for qw/ unused basic premium /;
-
-
-  # Print A Nice History Listing
-  printf( "\033[1m| %-20s | %-20s | %-30s | %-19s | %-19s | %-7s |\n\033[0m", 
-      "First Name", "Last Name", "Email Address", "Created", "Redeemed", "Type");
-
-  my @results = $VP->GetHistory; 
+  my $result = eval { $vp->GetUsage };
   
-  handle_error( $results[0] );
-
-  for my $obj ( $VP->GetHistory ) {
-      printf( "| %-20s | %-20s | %-30s | %-19s | %-19s | %-7s |\n", $obj->fname, 
-          $obj->lname, $obj->email, $obj->created, $obj->redeemed, $obj->type );
+  if ( $@ ) {
+      print "->GetUsage had an error: $@";
+  } else {
+      printf( "%7s => %5d\n", $_, $result->$_ ) for qw/ unused basic premium /;
   }
-
-
+  
+  
+  
+  my @results = $vp->GetHistory;
+  
+  if ( $@ ) {
+      print "->GetHistory had an error: $@";
+  } else {
+      for my $res ( @results ) {
+      printf( "| %-20s | %-20s | %-30s | %-19s | %-19s | %-7s |\n", $res->fname,
+          $res->lname, $res->email, $res->created, $res->redeemed, $res->type );
+      }
+  }
+  
   # Give Alan Shore a 'Golden Ticket' to VaultPress
-
-  my $ticket = $VP->CreateGoldenTicket(
+  
+  my $ticket = eval { $vp->CreateGoldenTicket(
       fname => 'Alan',
       lname => 'Shore',
       email => 'alan.shore@gmail.com',
-  ); handle_error( $ticket );
-
-  print "You can sign up for your VaultPress account <a href=\"" 
-      . $ticket->ticket ."\">Here!</a>\n";
+  ); };
+  
+  if ( $@ ) {
+      print "->CreateGoldenTicket had an error: $@";
+  } else {
+      print "You can sign up for your VaultPress account <a href=\""
+          . $ticket->ticket ."\">Here!</a>\n";
+  }
 
 =head1 DESCRIPTION
 
@@ -104,26 +100,6 @@ methods.
 
 =over 4
 
-=item is_success
-
-=over 4
-
-=item Set By
-
-WebService::VaultPress::Partner->CreateGoldenTicket
-WebService::VaultPress::Partner->GetHistory
-WebService::VaultPress::Partner->GetRedeemedHistory
-WebService::VaultPress::Partner->GetUsage
-
-=item Value Description
-
-Set 0 or 1.  1 Indicates a successful execution of the request and a successful response
-from the VaultPress API server.  0 indicates a failure to execute the request or a failure
-returned by the VaultPress API Server.  When set to 0 the response object is guaranteed
-to have an error method.
-
-=back
-
 =item api_call
 
 =over 4
@@ -143,24 +119,6 @@ and so on.
 
 =back
 
-=item error
-
-=over 4
-
-=item Set By
-
-WebService::VaultPress::Partner->CreateGoldenTicket
-WebService::VaultPress::Partner->GetHistory
-WebService::VaultPress::Partner->GetRedeemedHistory
-WebService::VaultPress::Partner->GetUsage
-
-=item Value Description
-
-An error string.  This is guaranteed to be set when ->is_success returns 0.
-Otherwise may be undef or may be "".
-
-=back
-
 =item ticket
 
 =over 4
